@@ -26,12 +26,14 @@ class Storage(object):
         self.lock = threading.RLock()
 
     @abstractmethod
-    def incr(self, key, expiry):
+    def incr(self, key, expiry, elastic_expiry=False):
         """
         increments the counter for a given rate limit key
 
         :param str key: the key to increment
         :param int expiry: amount in seconds for the key to expire in
+        :param bool elastic_expiry: whether to keep extending the rate limit
+         window every hit.
         """
         raise NotImplementedError
 
@@ -67,10 +69,9 @@ class MemoryStorage(Storage):
     def __expire_events(self):
         for key in self.events:
             for event in list(self.events[key]):
-                event.acquire()
-                if event.expiry > time.time() and event in self.events[key]:
-                    self.events[key].remove(event)
-                event.release()
+                with event:
+                    if event.expiry > time.time() and event in self.events[key]:
+                        self.events[key].remove(event)
         for key in list(self.expirations.keys()):
             if self.expirations[key] <= time.time():
                 self.storage.pop(key)
@@ -87,6 +88,8 @@ class MemoryStorage(Storage):
 
         :param str key: the key to increment
         :param int expiry: amount in seconds for the key to expire in
+        :param bool elastic_expiry: whether to keep extending the rate limit
+         window every hit.
         """
         self.get(key)
         self.storage[key] += 1
@@ -121,10 +124,9 @@ class MemoryStorage(Storage):
         except IndexError:
             entry = None
         if entry and entry.atime >= time.time() - expiry:
-            entry.acquire()
-            if entry in self.events[key]:
-                self.events[key].remove(entry)
-            entry.release()
+            with entry:
+                if entry in self.events[key]:
+                    self.events[key].remove(entry)
             return False
         else:
             if not no_add:
@@ -231,6 +233,8 @@ class MemcachedStorage(Storage):
 
         :param str key: the key to increment
         :param int expiry: amount in seconds for the key to expire in
+        :param bool elastic_expiry: whether to keep extending the rate limit
+         window every hit.
         """
         if not self.storage.add(key, 1, expiry, noreply=False):
             if elastic_expiry:
